nvector.tests package — nvector 0.7.5 documentation

# nvector.tests package

## Submodules

## nvector.tests.test_frames module

Created on 18. des. 2015

@author: pab

class `TestExamples`

  Bases: `object`

  `test_Ex10_cross_track_distance`(self)
  static `test_Ex1_A_and_B_to_delta_in_frame_N`()
  static `test_Ex2_B_and_delta_in_frame_B_to_C_in_frame_E`()
  static `test_Ex3_ECEF_vector_to_geodetic_latitude`()
  static `test_Ex4_geodetic_latitude_to_ECEF_vector`()
  static `test_Ex5_great_circle_distance`()
  static `test_Ex6_interpolated_position`()
  static `test_Ex7_mean_position`()
  static `test_Ex8_position_A_and_azimuth_and_distance_to_B`()
  static `test_Ex9_intersect`()
  static `test_alternative_great_circle_distance`()
  static `test_compute_delta_L_in_moving_frame_east`()
  static `test_compute_delta_L_in_moving_frame_north`()
  static `test_compute_delta_N_in_moving_frame_east`()
  static `test_exact_ellipsoidal_distance`()
  `test_intersect_on_parallell_paths`(self)

class `TestFrames`

  Bases: `object`

  `test_compare_B_frames`(self)
  `test_compare_E_frames`(self)
  `test_compare_L_frames`(self)
  `test_compare_N_frames`(self)

class `TestGeoPoint`

  Bases: `object`

  `test_scalar_geopoint_to_nvector_to_ecef_to_geopoint`(self)
  `test_scalar_geopoint_to_nvector_to_geopoint`(self)
  `test_vector_geopoint_to_nvector_to_ecef_to_geopoint`(self)
  `test_vector_geopoint_to_nvector_to_geopoint`(self)

`test_geo_path_on_path`(lat_a, lat_b, method)

## nvector.tests.test_geodesic module

class `GeodSolveTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `test_GeodSolve0`(self)
  `test_GeodSolve1`(self)
  `test_GeodSolve10`(self)
  `test_GeodSolve11`(self)
  `test_GeodSolve12`(self)
  `test_GeodSolve14`(self)
  `test_GeodSolve17`(self)
  `test_GeodSolve2`(self)
  `test_GeodSolve29`(self)
  `test_GeodSolve33`(self)
  `test_GeodSolve4`(self)
  `test_GeodSolve5`(self)
  `test_GeodSolve55`(self)
  `test_GeodSolve6`(self)
  `test_GeodSolve9`(self)

class `GeodesicTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `test_direct`(self)
  `test_inverse`(self)

## nvector.tests.test_nvector module

This file contains solutions to the examples given at www.navlab.net/nvector

The content of this file is based on the following publication:

Gade, K. (2010). A Nonsingular Horizontal Position Representation, The Journal of Navigation, Volume 63, Issue 03, pp 395-417, July 2010. (www.navlab.net/Publications/A_Nonsingular_Horizontal_Position_Representation.pdf)

Copyright (c) 2015, Norwegian Defence Research Establishment (FFI) All rights reserved.

Originated: 2015.03.26 Kenneth Gade, FFI

NOTES: - All angles are by default assumed to be in radians, if an angle is in degrees, the variable name has the following ending: _deg

- The dot product (inner product) of vectors x and y is written dot(x,y).

class `TestNvector`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  static `test_Ex10_cross_track_distance`()
  static `test_Ex1_A_and_B_to_delta_in_frame_N`()
  static `test_Ex2_B_and_delta_in_frame_B_to_C_in_frame_E`()
  static `test_Ex3_ECEF_vector_to_geodetic_latitude`()
  static `test_Ex4_geodetic_latitude_to_ECEF_vector`()
  static `test_Ex5_great_circle_distance`()
  static `test_Ex6_interpolated_position`()
  static `test_Ex7_mean_position`()
  static `test_Ex8_position_A_and_azimuth_and_distance_to_B`()
  static `test_Ex9_intersect`()
  static `test_R2xyz`()
  static `test_R2xyz_with_vectors`()
  static `test_R2zxy`()
  static `test_R2zxy_0`()
  static `test_R2zxy_x90`()
  static `test_R2zxy_y90`()
  static `test_R2zxy_z90`()
  static `test_n_EA_E_and_n_EB_E2azimuth`()
  static `test_n_E_and_wa2R_EL`()
  `test_small_and_large_cross_track_distance`(self)

## Module contents